@@ -2,5 +2,6 @@ from munzee.endpoints.clan import Clans
 from munzee.endpoints.map import Map
 from munzee.endpoints.munzee import Munzees
 from munzee.endpoints.player import Players
+from munzee.endpoints.statzee import Statzee
 
-__all__ = ["Players", "Munzees", "Map", "Clans"]
+__all__ = ["Players", "Munzees", "Map", "Clans","Statzee"]
