@@ -7,7 +7,7 @@ import json
 
 import requests
 
-from munzee.endpoints import Clans, Map, Munzees, Players
+from munzee.endpoints import Clans, Map, Munzees, Players, Statzee
 
 
 class Munzee:
@@ -25,6 +25,7 @@ class Munzee:
         self.munzees = Munzees(self.base_requester)
         self.map = Map(self.base_requester)
         self.clans = Clans(self.base_requester)
+        self.statzee = Statzee(self.base_requester)
 
     class Requester(object):
         """Api requesting object"""
